==> gbsite-1.0.0.tar.gz: gbsite/templates/gb/gb_aboutpage.php <==
<table cellspacing="0" cellpadding="2" border="0" width="100%">
<tr>
<td><img src="<?= $image_path ?>/shim.gif" width="20" height="1"></td>
<td>
<font face="<?= $font_1 ?>" size="2">
<p>Great Bridge was established in May 2000 for the purpose of professionally marketing and supporting open source software solutions based on PostgreSQL.</p>
<p>Great Bridge will:</p>
<ul>
<li>Empower today's e-business builders with an enterprise-class database and tools at a fraction of the cost of proprietary commercial alternatives. With easy access to the underlying source code, business users need never be trapped in a &quot;closed&quot; vendor solution again.
<br><br>
<li>Integrate PostgreSQL with best-of-breed open source technologies to allow for rapid development and deployment of web-based applications.
<br><br>
<li>Deliver exceptional service and support, staffed with knowledgeable software engineering experts, including developers from each of the open source projects we support.
</ul>
<p>Great Bridge is a privately held company funded by <a href="http://www.landmarkcom.com" target="_blank">Landmark Communications</a>, Inc., a media company based in Norfolk, Virginia that also owns The Weather Channel, <a href="http://www.weather.com" target="blank">weather.com</a>, and national and international newspapers, broadcasting, electronic publishing, and specialty media outlets.</p>
<p>Meet our <a href="/about/ourteam.php">management team</a>.</p>
</font>
</td>
</tr>
<tr>
<td colspan="2"><img src="<?= $image_path ?>/shim.gif" width="1" height="20"></td>
</tr>
<tr>
<td colspan="2"><font face="<?= $font_1 ?>" size="2"><b>The open source development process produces better software.</b></font></td>
</tr>
<tr>
<td><img src="<?= $image_path ?>/shim.gif" width="20" height="1"></td>
<td>
<font face="<?= $font_1 ?>" size="2">This fundamental belief is at the heart of what we do. It's the same belief that led our chairman, Frank Batten Jr., to invest in Red Hat, Inc. in 1996, at a time when most investors scoffed at open source technologies and business models.  As the largest single Red Hat shareholder and former company director, Batten observed first hand the rapid improvement and enhancement of the Linux operating system.  He saw that open source technologies were innovating at a faster rate than what could be done at the proprietary software companies.  So he challenged a team of executives at Landmark Communications to look into open source solutions beyond operating systems.   This team found the following:
<ul>
<li><i>SEVERAL</i> open source projects rivaled the best of proprietary or closed applications in terms of performance, features and functionality.
<br><br>
<li><i>MOST</i> of these technologies would be viable alternatives for businesses currently paying exorbitant license fees to proprietary vendors and receiving poor service and support for their money.
<br><br>
<li><i>FEW</i> of these open source technologies had a strong, viable company standing behind them to provide commercial releases, services and support.
<br><br>
<li><i>POSTGRESQL</i> stood out among open source applications - with a compelling combination of robust features and performance, a strong development community, and a license that would be acceptable to business customers.
</ul>
</font>
</td>
</tr>
<tr>
<td colspan="2"><img src="<?= $image_path ?>/shim.gif" width="1" height="20"></td>
</tr>
<tr>
<td colspan="2"><font face="<?= $font_1 ?>" size="2"><b>Working with the PostgreSQL community.</b></font></td>
</tr>
<tr>
<td><img src="<?= $image_path ?>/shim.gif" width="20" height="1"></td>
<td>
<font face="<?= $font_1 ?>" size="2"">
<p>In March 2000, Great Bridge hosted the first ever face-to-face meeting of the PostgreSQL core steering group. The result was a three-day meeting in San Francisco at which the developers and Great Bridge agreed to coordinate their respective efforts on technology improvements, with Great Bridge focusing on identifying key product and service features required by business customers.</p>
<p>Great Bridge has also established a testing and integration lab and initiated the most comprehensive <a href="/about/presslist.php">benchmark tests</a> of PostgreSQL to date to give technology buyers fair and accurate product performance comparisons.</p>
<p>In May 2000, Great Bridge publicly announced its funding to coincide with the release of PostgreSQL version 7.0.</p>
</font>
</td>
</tr>
<tr>
<td colspan="2"><img src="<?= $image_path ?>/shim.gif" width="1" height="20"></td>
</tr>
<tr>
<td colspan="2"><font face="<?= $font_1 ?>" size="2"><b>What's in a name?</b></font></td>
</tr>
<tr>
<td><img src="<?= $image_path ?>/shim.gif" width="20" height="1"></td>
<td>
<font face="<?= $font_1 ?>" size="2"">
<p>The name Great Bridge is taken from a local Virginia landmark where, on December 9, 1775, a group of rebels fighting for open self-government and freedom from a monopolistic empire won a pivotal battle that triggered the end of British Crown rule in its most valuable American colony.</p>
<p>Like the original participants of this decisive battle, we believe strongly in self-determination and freedom.  For too long, the world of business software has been monopolized by powerful companies who, by keeping their source code closed, have dictated the speed and direction of software development.  We strongly believe that our support of open source technology standards for business will help usher in a new era of business growth and technology development for businesses of every size.</p>
</font>
</td>
</tr>
</table>

==> gbsite-1.1.0.tar.gz: gbsite/templates/gb/gb_aboutpage.php <==
<table cellspacing="0" cellpadding="2" border="0" width="100%">
<tr>
<td><img src="<?= $image_path ?>/shim.gif" width="20" height="1"></td>
<td>
<font face="<?= $font_1 ?>" size="2">
<p>Founded in May 2000, Great Bridge delivers open source software solutions powered by PostgreSQL, the world's most advanced open source database.</p>
<p>At Great Bridge, we believe in the enormous power of the open source development process to produce better, lower cost software with fewer bugs, faster enhancement cycles and more user control than closed, legacy software from proprietary vendors.</p>
<p>Great Bridge:</p>
<ul>
<li>Empowers today's e-business builders with an enterprise-class database and tools at a fraction of the cost of proprietary commercial alternatives. With easy access to the underlying source code, business users need never be trapped in a &quot;closed&quot; vendor solution again.
<br><br>
<li>Delivers exceptional service and support, staffed with knowledgeable software engineering experts, including key developers from the PostgreSQL project. By assembling the largest repository of PostgreSQL expertise in the world, Great Bridge provides unparalleled experience and know-how for deploying the power of PostgreSQL.
<br><br>
<li>Provides database expertise for every stage of the software development lifecycle -- from developer support for building applications to consulting services for integrating applications to technical support for deploying and managing applications.
</ul>
<p>Great Bridge is a privately held company funded by <a href="http://www.landmarkcom.com" target="_blank">Landmark Communications</a>, Inc., a media company based in Norfolk, Virginia that also owns The Weather Channel, <a href="http://www.weather.com" target="blank">weather.com</a>, and national and international newspapers, broadcasting, electronic publishing, and specialty media outlets.</p>
<p>Meet our <a href="/about/ourteam.php">management team</a>.</p>
</font>
</td>
</tr>
<tr>
<td colspan="2"><img src="<?= $image_path ?>/shim.gif" width="1" height="20"></td>
</tr>
<tr>
<td colspan="2"><font face="<?= $font_1 ?>" size="2"><b>The open source development process produces better software.</b></font></td>
</tr>
<tr>
<td><img src="<?= $image_path ?>/shim.gif" width="20" height="1"></td>
<td>
<font face="<?= $font_1 ?>" size="2">This fundamental belief is at the heart of what we do. It's the same belief that led our chairman, Frank Batten Jr., to invest in Red Hat, Inc. in 1996, at a time when most investors scoffed at open source technologies and business models.  As the largest single Red Hat shareholder and former company director, Batten observed first hand the rapid improvement and enhancement of the Linux operating system.  He saw that open source technologies were innovating at a faster rate than what could be done at the proprietary software companies.  So he challenged a team of executives at Landmark Communications to look into open source solutions beyond operating systems.   This team found the following:
<ul>
<li><i>SEVERAL</i> open source projects rivaled the best of proprietary or closed applications in terms of performance, features and functionality.
<br><br>
<li><i>MOST</i> of these technologies would be viable alternatives for businesses currently paying exorbitant license fees to proprietary vendors and receiving poor service and support for their money.
<br><br>
<li><i>FEW</i> of these open source technologies had a strong, viable company standing behind them to provide commercial releases, services and support.
<br><br>
<li><i>POSTGRESQL</i> stood out among open source applications - with a compelling combination of robust features and performance, a strong development community, and a license that would be acceptable to business customers.
</ul>
</font>
</td>
</tr>
<tr>
<td colspan="2"><img src="<?= $image_path ?>/shim.gif" width="1" height="20"></td>
</tr>
<tr>
<td colspan="2"><font face="<?= $font_1 ?>" size="2"><b>Working with the PostgreSQL community.</b></font></td>
</tr>
<tr>
<td><img src="<?= $image_path ?>/shim.gif" width="20" height="1"></td>
<td>
<font face="<?= $font_1 ?>" size="2"">
<p>In March 2000, Great Bridge hosted the first ever face-to-face meeting of the PostgreSQL core steering group. The result was a three-day meeting in San Francisco at which the developers and Great Bridge agreed to coordinate their respective efforts on technology improvements, with Great Bridge focusing on identifying key product and service features required by business customers.</p>
<p>Great Bridge has also established a testing and integration lab and initiated the most comprehensive <a href="/about/presslist.php">benchmark tests</a> of PostgreSQL to date to give technology buyers fair and accurate product performance comparisons.</p>
<p>In May 2000, Great Bridge publicly announced its funding to coincide with the release of PostgreSQL version 7.0.</p>
</font>
</td>
</tr>
<tr>
<td colspan="2"><img src="<?= $image_path ?>/shim.gif" width="1" height="20"></td>
</tr>
<tr>
<td colspan="2"><font face="<?= $font_1 ?>" size="2"><b>What's in a name?</b></font></td>
</tr>
<tr>
<td><img src="<?= $image_path ?>/shim.gif" width="20" height="1"></td>
<td>
<font face="<?= $font_1 ?>" size="2"">
<p>The name Great Bridge is taken from a local Virginia landmark where, on December 9, 1775, a group of rebels fighting for open self-government and freedom from a monopolistic empire won a pivotal battle that triggered the end of British Crown rule in its most valuable American colony.</p>
<p>Like the original participants of this decisive battle, we believe strongly in self-determination and freedom.  For too long, the world of business software has been monopolized by powerful companies who, by keeping their source code closed, have dictated the speed and direction of software development.  We strongly believe that our support of open source technology standards for business will help usher in a new era of business growth and technology development for businesses of every size.</p>
</font>
</td>
</tr>
</table>
